Learn R Programming

GmooG (version 0.7)

DC1912adjourns: Times of adjournments at the 1912 Democratic Convention

Description

Times that the six adjournments started and finished, taken from Woodson's convention report.

Usage

data(DC1912adjourns)

Arguments

Format

A data frame with 6 observations on the following 2 variables.

StartT

Date and time of start of adjournment

EndT

Date and time of end of adjournment

Details

This dataset is used in combination with the datasets DC1912 and DC1912ballots for the final plot of Chapter 4 (Figure 4.7), "Voting 46 times to choose a Presidential candidate".

Examples

Run this code
data(DC1912adjourns, package="GmooG")
DC1912adjourns

Run the code above in your browser using DataLab