Learn R Programming

GmooG (version 0.7)

DC1912dels: Numbers of delegates for the individual states and groups

Description

The number of pledged delegates by group at the 2020 Democratic convention.

Usage

data(DC1912dels)

Arguments

Format

A data frame with 58 observations on the following 3 variables.

State

Name of group (mostly state or territory)

TotP

Number of pledged delegates by group at the 2020 Democratic convention

region

Ordered factor: MidWest, NorthEast, West, South, Territory, NA

Details

This dataset is used in Chapter 4, "Voting 46 times to choose a Presidential candidate".

Examples

Run this code
data(DC1912dels, package="GmooG")
head(DC1912dels)

Run the code above in your browser using DataLab