Learn R Programming

GmooG (version 0.7)

France1954: Working population of France in 1954

Description

Numbers working in three sectors in each department of France in 1954.

Usage

data(F1954)

Arguments

Format

A data frame with 90 observations on the following 8 variables.

ID

ID code for the department

Dept

Department name

I.Agriculture

Number in thousands of workers in agriculture

II.Industry

Number in thousands of workers in industry

III.Commerce

Number in thousands of workers in commerce

BertinTotal

Total of the three sectors reported by Bertin

Area

Area of department in sq kms

NOM_DEPT

Alternative name for department

Details

The sector data is from Bertin, while area data has been taken from the Guerry package and Wikipedia. The alternative department name was used for merging with a shape file of France (France54Map). The dataset is analysed in Chapter 7, "Re-viewing Bertin's main example".

Examples

Run this code
data(F1954, package="GmooG")
with(F1954, summary(I.Agriculture))

Run the code above in your browser using DataLab