Learn R Programming

GmooG (version 0.7)

GmooG: GmooG: datasets analysed in "Getting (more out of) Graphics"

Description

There are 25 chapters of graphical data analyses in the book. Datasets that are not readily available are mainly provided in this package.

Arguments

Author

Antony Unwin unwin@math.uni-augsburg.de

Details

Other datasets are analysed in the book as well. They are available in various R packages. Some can be downloaded and updated from the web.