Learn R Programming

GmooG (version 0.7)

USregions: Map of the Regional Classification of the contiguous US States

Description

Map of the contiguous US States including information on the regional classification by the Census Bureau

Usage

data(USregions)

Arguments

Format

A data frame with 49 observations on 4 variables.

NAME

name of state

State

2-letter code for state

Region

one of four Census Bureau regions: NorthEast, South, MidWest, West

geometry

map polygons for state

Details

This dataset is used in Chapter 9, "Results from surveys on gay rights".

Examples

Run this code
data(USregions, package="GmooG")

Run the code above in your browser using DataLab